@@ -11,7 +11,7 @@ import pango
 import hashlib          
 import StringIO
 DB_FORMAT = '%Y-%m-%d'
-FRAMEWORK_VERSION = '0.2.0' 
+FRAMEWORK_VERSION = '0.2.1' 
 DB_PATH = '/home/user/.mPIM/mnotes.db'
 DB_IMG_FOLDER = '/home/user/.mPIM/mnotes_img/'
 
@@ -66,6 +66,9 @@ class Database:
 #              self.cursor.execute('ALTER TABLE notes ADD COLUMN photo BINARY')
 #              self.cursor.execute('ALTER TABLE notes ADD COLUMN draw BINARY')
               self.db.commit()
+            if version < '0.2.1':
+                self.cursor.execute('ALTER TABLE notes ADD COLUMN type INTEGER')
+
           except:
             pass
 
@@ -114,6 +117,11 @@ class Note:
             self.have_photo = False
             self.have_draw = False
 
+            #0 -> Text
+            #1  -> Draw
+            #2 ->  Image
+            self.type = 0
+
             if suuid=='':
               self.uuid = uuid.uuid4().__str__()
               self.new = True
@@ -124,14 +132,16 @@ class Note:
 
         def test_have_photo(self):
           if os.path.exists(self.get_photo_path())==False:
-            self.photo = False
+            self.have_photo = False
           else:
-            self.photo=True
+            self.have_photo=True
+
         def test_have_draw(self):
           if os.path.exists(self.get_draw_path())==False:
-            self.draw = False
+            self.have_draw = False
           else:
-            self.draw=True
+            self.have_draw =True
+
         def get_photo_path(self):
           if os.path.exists('/home/user/.mPIM/mnotes_img/')==False:
             commands.getoutput("mkdir /home/user/.mPIM/mnotes_img/")
@@ -143,11 +153,15 @@ class Note:
 
         def load_from_db(self,suuid):
             db = Database(DB_PATH)
-            db.cursor.execute('SELECT title, description FROM notes where uuid="'+suuid+'"')
+            db.cursor.execute('SELECT title, description,type FROM notes where uuid="'+suuid+'"')
             for note in db.cursor.fetchall():
               self.description = note[1]
               self.title = note[0]
               self.new = False
+              if note[2] != None:
+                self.type = int(note[2])
+              else:
+                self.type = 0
             self.test_have_draw()
             self.test_have_photo()
             db.close()
@@ -157,10 +171,10 @@ class Note:
               self.title = self.description.split('\n')[0]
             db = Database(DB_PATH)
             if self.new==True:
-              db.cursor.execute('INSERT INTO notes (uuid , title, description ) VALUES(?,?,?);',[self.uuid,self.title,self.description])
+              db.cursor.execute('INSERT INTO notes (uuid , title, description,type ) VALUES(?,?,?,?);',[self.uuid,self.title,self.description,self.type])
               db.db.commit()
             else:
-              db.cursor.execute('UPDATE notes SET title=?, description=? WHERE uuid=?;',[self.title,self.description,self.uuid])
+              db.cursor.execute('UPDATE notes SET title=?, description=?, type=? WHERE uuid=?;',[self.title,self.description,self.type,self.uuid])
               db.db.commit()
             db.close()
 
