@@ -32,23 +32,25 @@ def ask_dialogue(win,message):
     return True
   else:
     return False
-    
+
 class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.2.5"
+  __version__ = "0.2.6"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
-    #'/usr/lib/mnotes/ui/mnotes.glade',
-    'ui/mnotes.glade',
+    '/usr/lib/mnotes/ui/mnotes.glade',
+    #'ui/mnotes.glade',
   ]
 
   def __init__(self,app,context):
     self._callbackList = None
     self._search_text = None
-
+    self._cam_display = False
+    self._image_sized = False
+    
     for path in mNotes._glade_files:
       if os.path.isfile(path):
         self._widgetTree = gtk.glade.XML(path)
@@ -100,7 +102,7 @@ class mNotes(object):
     self._imagewin = self._widgetTree.get_widget("ImageView")
     self._textwin = self._widgetTree.get_widget("TextView")
     self._drawwin = self._widgetTree.get_widget("DrawingView")
-    
+
     self._bTitlePict = self._widgetTree.get_widget("bTitlePict")
     self._bTitleDraw= self._widgetTree.get_widget("bTitleDraw")
 
@@ -126,7 +128,7 @@ class mNotes(object):
 
     self._load_hpane_position()
     self._current_selection_iter = None
-    
+
     if self._window:
       self._children_color_bg(self._window)
       self._window.connect("delete-event", self._win_closebox)
@@ -160,6 +162,8 @@ class mNotes(object):
 #      self._load_current_note_draw()
 
   def _switch_view(self,view):
+    if self._cam_display == True:
+      threading.Thread(target=self.stop_cam).start()
     if view == 0:
       self._imagewin.hide()
       self._textwin.show()
@@ -176,20 +180,37 @@ class mNotes(object):
       self._textwin.hide()
       self._drawwin.hide()
 
+  def on_size_allocate(self,widget, allocation, *args):
+    if self._image_sized == False:
+      self._load_current_note_pict()
+    self._image_sized = not self._image_sized
+    
   def _load_current_note_pict(self):
     if self._current_note.have_photo == False:
       self._photoview.set_from_stock(gtk.STOCK_MISSING_IMAGE,gtk.ICON_SIZE_DND)
     else:
-      pixbuf = gtk.gdk.pixbuf_new_from_file_at_scale(self._current_note.get_photo_path(),320,240,gtk.gdk.INTERP_BILINEAR)
+#      self._photoview.set_size_request(800,600)
+      w,h = self._photoview.get_parent().get_parent().size_request()
+#      w = self._photoview.get_parent_window().width
+#      h = self._photoview.get_parent_window().height
+#      w = self._photoview.get_screen().get_width_mm()
+#      h = self._photoview.get_screen().get_height_mm()
+      w,h = (self._photoview.get_allocation().width,self._photoview.get_allocation().height)
+#      w = self._photoview.window.width
+#      h = self._photoview.height
+#      print str(w)+':'+str(h)
+      pixbuf = gtk.gdk.pixbuf_new_from_file_at_scale(self._current_note.get_photo_path(),w,h,gtk.gdk.INTERP_BILINEAR)
       if pixbuf == None:
-        pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 320, 240)
+        pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, w, h)
       try:
 #        w,h = (pixbuf.get_width(),pixbuf.get_height())
 #        scaled_buf = pixbuf.scale_simple(320,h/(w/320),gtk.gdk.INTERP_BILINEAR)
         self._photoview.set_from_pixbuf(pixbuf)
+        del pixbuf
       except StandardError,e:
         print e
         pass
+      
 
   def _load_current_note_draw(self):
     if self._current_note.have_draw == True:
@@ -225,7 +246,7 @@ class mNotes(object):
 
   def _save_current_note(self):
     if self._current_note != None:
-    
+
       if self._current_note.type == 0:
         buffer = self._editor.get_buffer()
         start, end = buffer.get_bounds ()      
@@ -246,7 +267,7 @@ class mNotes(object):
       elif self._current_note== 2:  
         if (self._current_selection_iter):
           uuid = self._notesList.set_value(self._current_selection_iter, 1,self._current_note.title)
-  
+
       self.refresh()
       #self._load_noteslist_bg()
 
@@ -266,9 +287,12 @@ class mNotes(object):
       #Load photo
       if (self._current_note.type == 2) :
         self._bTitlePict.set_text(self._current_note.title)
-        self._load_current_note_pict()
-        #self._photoview.set_from_file(self._current_note.get_photo_path())
         self._switch_view(self._current_note.type)
+#        self._load_current_note_pict()
+        self._photoview.clear()
+        #set_size_request(-1,-1)
+        #self._photoview.set_from_file(self._current_note.get_photo_path())
+        
       #load draw here only when the drawingarea have window so when selected page on the notebook
       elif (self._current_note.type == 1) :
         self._bTitleDraw.set_text(self._current_note.title)
@@ -279,6 +303,8 @@ class mNotes(object):
     return
 
   def _search_note(self,widget):
+    if self._cam_display == True:
+      threading.Thread(target=self.stop_cam).start()
     self._search_text = self._widgetTree.get_widget("SearchTexte").get_text()
     self._load_noteslist_bg()
 
@@ -313,6 +339,8 @@ class mNotes(object):
     self.notesListTree.queue_draw()
 
   def _add_image(self,widget, *args):
+    if self._cam_display == True:
+      threading.Thread(target=self.stop_cam).start()
     dialog = hildon.FileChooserDialog(self._window, "open")
     if(dialog.run()==gtk.RESPONSE_OK) and (dialog.get_filename()!=None):
       try:
@@ -320,7 +348,9 @@ class mNotes(object):
         dialog.destroy()
 #        self.open_file(filename)
         shutil.copyfile(filename, self._current_note.get_photo_path())
-        self._load_current_note_pict()
+        self._photoview.clear()
+        #set_size_request(-1,-1)
+#        self._load_current_note_pict()
 #        pixbuf = gtk.gdk.pixbuf_new_from_file(self._current_note.get_photo_path())
 #        w,h = (pixbuf.get_width(),pixbuf.get_height())
 #        scaled_buf = pixbuf.scale_simple(320,h/(w/320),gtk.gdk.INTERP_BILINEAR)
@@ -330,8 +360,8 @@ class mNotes(object):
         print e
         dialog.destroy()
         self.alert_dialog(e.__str__())
-      else:
-        dialog.destroy()
+    else:
+      dialog.destroy()
 
   def alert_dialog(self,message):
     dialog = gtk.MessageDialog(self,
@@ -352,6 +382,8 @@ class mNotes(object):
     self._add_note(2)
 
   def _add_note(self,note_type):
+    if self._cam_display == True:
+      threading.Thread(target=self.stop_cam).start()
     self._save_current_note()
     note = mnotes_framework.Note('')
     note.type = note_type
@@ -408,6 +440,8 @@ class mNotes(object):
     self._editor = self._widgetTree.get_widget("Editor")
     self._editor.get_buffer().set_text('Welcome to mnotes !')
     self._photoview =self._widgetTree.get_widget("PhotoView")
+    self._photoview.connect('size-allocate',self.on_size_allocate)
+    
     self._draw_x,self._draw_y,self._draw_old_x,self._draw_old_y = (0,0,0,0)
     self._draw_mode = 1
     self._draw_same = False
@@ -588,7 +622,8 @@ class mNotes(object):
     from easy import camera
     camera.click(self._current_note.get_photo_path())
     self._current_note.test_have_photo()
-    self._load_current_note_pict()
+    self._photoview.clear() #set_size_request(-1,-1)
+#    self._load_current_note_pict()
 #    pixbuf = gtk.gdk.pixbuf_new_from_file(self._current_note.get_photo_path())       
 #    w,h = (pixbuf.get_width(),pixbuf.get_height())
 #    scaled_buf = pixbuf.scale_simple(320,h/(w/320),gtk.gdk.INTERP_BILINEAR)
@@ -612,7 +647,9 @@ class mNotes(object):
     from easy import camera
     camera.stop_display()
     self._widgetTree.get_widget("Photo").hide()
+    self._widgetTree.get_widget("bPick").set_state(False)
     self._photoview.show()
+    self._cam_display = False
     gtk.gdk.threads_leave()
 
   def start_cam(self):
@@ -620,11 +657,12 @@ class mNotes(object):
     from easy import camera
     self._widgetTree.get_widget("Photo").show()
     self._photoview.hide()
+    self._cam_display = True
 #    camera.display(resolution=camera.RESOLUTION_640x480)
 #    print type(self._widgetTree.get_widget("drawingarea1").window.xid)
 #    self._widgetTree.get_widget("drawingarea1").show()
 #    self._widgetTree.get_widget("xwindow").set_size_request(64,48)
-    
+
 #    while (self._widgetTree.get_widget("Photo").window == None):
 #      time.sleep(1)
     gtk.gdk.threads_leave()
